#!/usr/bin/env python

# (c) Copyright [2020 - 2021] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (Micro Focus) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions
# contained herein. The information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential information
# and a valid license is required for possession, use or copying. If this work is provided to the
# U.S. Government, consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items are licensed
# to the U.S. Government under vendor's standard commercial license.

import os
import json
import fcntl
import commands
from time import strptime, mktime
from collections import OrderedDict

novellNitJsonFile = "/var/opt/novell/nit/novell-nit.json"
novellNitLogFile = "/var/opt/novell/log/nit/nit.log"

#Write the health of NIT service to /var/opt/novell/nit/nit.json
def writeJSON(dictionary):
	try:
		with open(novellNitJsonFile, "w") as nitstatusfile:
			fcntl.flock(nitstatusfile, fcntl.LOCK_EX | fcntl.LOCK_NB)
			json.dump(dictionary, nitstatusfile, indent=4, separators=(", ", ": "))
			fcntl.flock(nitstatusfile, fcntl.LOCK_UN)
	except IOError:
		raise Exception("Failed to open/write the Json file", novellNitJsonFile)

#Get NIT Health status data
def genHealthStatus():
	nitsystemctl_cmd = "systemctl is-active novell-nit"
	nitstatus = commands.getoutput(nitsystemctl_cmd)
	jsonnit_stream = OrderedDict()
	jsonnit_stream["serviceName"] = "Novell Identity Translator(NIT)"
	jsonnit_stream["status"] = ""
	jsonnit_stream["runningSince"] = ""
	jsonnit_stream["AdditionalInfo"] = ""
	jsonnit_stream["children"] = None

	check_admode ,admode_output = commands.getstatusoutput("cat /etc/opt/novell/nit/nitd.conf | grep ad-mode=yes")
	dcportconn,dcportconn_output = commands.getstatusoutput("netstat -nap | grep nitd | grep :389 | grep ESTABLISHED")
	gcportconn,gcportconn_output1 = commands.getstatusoutput("netstat -nap | grep nitd | grep :3268 | grep ESTABLISHED")

	if(nitstatus == "inactive"):
		jsonnit_stream["status"] = ("UnHealthy")
		jsonnit_stream["runningSince"] = 0
		jsonnit_stream["AdditionalInfo"] = ["NIT service","Common_Inactive","Common_ResolveService"]
	else:
		nittimestamp_cmd = "systemctl show -p ExecMainStartTimestamp novell-nit"
		nittimestatus = commands.getoutput(nittimestamp_cmd)
		timestamp_output = nittimestatus.strip().split("=")
		target_timestamp = strptime(timestamp_output[1], '%a %Y-%m-%d %H:%M:%S %Z')
		epoch_time = mktime(target_timestamp)
		jsonnit_stream["status"] = ("Healthy")
		jsonnit_stream["runningSince"] = int(epoch_time)

		# checking if ad-mode is "yes". If ad-mode=yes, then checking both ports 389 and 3268 present in netstat
		if (check_admode == 0):
			if (dcportconn == 0) and (gcportconn == 0):
				jsonnit_stream["status"] = ("Healthy")
			else:
				jsonnit_stream["status"] = ("UnHealthy")
				jsonnit_stream["AdditionalInfo"] = ["Err_NIT_NoADConnections","Common_ReferLogMoreInfo",novellNitLogFile] 
	return jsonnit_stream

healthData = genHealthStatus()

try:
	writeJSON(healthData)
except Exception:
	exit(1)

